#
# spec file for package python-zope.i18nmessageid
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2013-2022 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-zope.i18nmessageid%{psuffix}
Version:        7.0
Release:        2.1
Summary:        Zope Location
License:        ZPL-2.1
URL:            https://github.com/zopefoundation/zope.i18nmessageid
Source:         https://files.pythonhosted.org/packages/source/z/zope.i18nmessageid/zope_i18nmessageid-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION documentation requirements
BuildRequires:  python3-Sphinx
BuildRequires:  python3-sphinx_rtd_theme
# /SECTION
# SECTION testing requirements
%if %{with test}
BuildRequires:  %{python_module zope.i18nmessageid}
%endif
%python_subpackages

%description
In Zope3, i18nmessageid are special objects that has a structural i18nmessageid.

%package     -n %{name}-doc
Summary:        Zope Location
Provides:       %{python_module zope.i18nmessageid-doc = %{version}}
BuildArch:      noarch

%description -n %{name}-doc
This package contains documentation files for %{name}.

%prep
%autosetup -p1 -n zope_i18nmessageid-%{version}
rm -rf zope.i18nmessageid.egg-info

%build
%if !%{with test}
%pyproject_wheel
sphinx-build -b html docs build/sphinx/html && rm -r build/sphinx/html/.{buildinfo,doctrees} build/sphinx/html/objects.inv
%endif

%install
%if !%{with test}
%pyproject_install
# don't bother with development files
%{python_expand rm -f %{buildroot}%{$python_sitearch}/zope/i18nmessageid/_zope_i18nmessageid_message.c
  %fdupes %{buildroot}%{$python_sitearch}
}
%endif

%check
%if %{with test}
%pyunittest 'zope.i18nmessageid.tests.test_suite'
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst COPYRIGHT.txt README.rst
%dir %{python_sitearch}/zope
%{python_sitearch}/zope/i18nmessageid
%{python_sitearch}/zope.i18nmessageid-%{version}.dist-info
%{python_sitearch}/zope.i18nmessageid-%{version}*-nspkg.pth
%endif

%if !%{with test}
%files -n %{name}-doc
%doc build/sphinx/html/
%endif

%changelog
* Wed Jan 22 2025 Steve Kowalik <steven.kowalik@suse.com>
- Explicitly BuildRequire sphinx_rtd_theme.
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- update to 7.0:
  * Drop support for Python 3.7.
  * Build Windows wheels on GHA.
  * Add support for Python 3.13.
  * Enable multi-phase module initialization (PEP 489) for all
    supported Python versions.  See this "how-to" doc for
    rationale and steps:
    https://docs.python.org/3.13/howto/isolating-extensions.html
  * Make the hookable extension type heap-allocated for Python >=
    3.9. Likewise, see the doc above for rationale and steps.
    For Python < 3.9, the hookable extension type continues to be
    allocated statically, even though the module itself is
    allocated dynamically.
- drop fix-intersphinx-mapping.patch (obsolete)
* Wed Sep 11 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch fix-intersphinx-mapping.patch:
  * Fix the intersphinx mapping.
- Switch to autosetup macro.
* Tue Jan  2 2024 Dirk Müller <dmueller@suse.com>
- update to 6.1.0:
  * Add support for Python 3.12.
* Wed Jul 26 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop sphinx doctrees for reproducible builds
* Fri May  5 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.1:
  * Drop dependency on ``six``.
  * Drop support for Python 2.7, 3.5, 3.6.
  * Add preliminary support for Python 3.12a5.
* Wed May  3 2023 Martin Liška <mliska@suse.cz>
- Use sphinx-build and do not depend on removed build_sphinx
  in Sphinx 7.0 (boo#1211051).
* Wed Feb  1 2023 Ben Greiner <code@bnavigator.de>
- Explicitly require python3-Sphinx for building the docs. It could
  have been omitted from %%pythons for %%python_module in a 15.X
  backport project.
* Mon Dec  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.1.1
  * Add support for building arm64 wheels on macOS.
* Tue Nov  8 2022 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file, make rpmlint happy.
- -doc subpackage should be noarch.
* Sun Nov  6 2022 Hans-Peter Jansen <hpj@urpla.net>
- update to version 5.1.0
  * Added support for Python 3.9, 3.10 and 3.11.
* Wed Oct 13 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
- added sources
  + _multibuild
* Wed Apr  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in python2 pkg in doc subpkg
* Mon Mar 16 2020 pgajdos@suse.com
- version update to 5.0.1
  - Remove deprecated use of setuptools features.  See `issue 22
    <https://github.com/zopefoundation/zope.i18nmessageid/issues/22>`_.
* Tue Jan 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 5.0.0
  * Drop support for Python 3.4.
  * Add support for Python 3.8.
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Fri Apr  5 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.3.1
  * Drop support for Python 3.3.
  * Add support for Python 3.7.
  * Fix the possibility of a rare crash in the C extension when
    deallocating items.
  * Add attributes to support pluralization on a Message and update
    the MessageFactory accordingly.
  * Fix a regression copying Message objects in the Python
    implementation.
* Sat Jul  8 2017 aloisio@gmx.com
- Update to version 4.1.0
  * Drop support for Python 2.6 and 3.2.
  * Add support for Python 3.5 and 3.6.
  * Fix the C extension not being used in Python 3. See issue 4.
  * Make the Python implementation of Message accept any object
    for the default argument, just as the C extension does.
    This should be a unicode or byte string. See issue 5.
- Converted to single-spec
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.0.3:
  * Added support for Python 3.4.
  * Updated boostrap.py to version 2.2.
- rename CHANGES.txt to CHANGES.rst: changed upstream
- rename README.txt to README.rst: changed upstream
* Fri Dec 27 2013 p.drouand@gmail.com
- Package CHANGES.txt, COPYRIGHT.txt, LICENSE.txt and README.txt
- Use download Url as source
* Mon Jul 29 2013 hpj@urpla.net
- version 4.0.2: initial build
